@@ -53,7 +53,10 @@ typedef enum {
 	GDA_CONNECTION_NO_CNC_SPEC_ERROR,
 	GDA_CONNECTION_NO_PROVIDER_SPEC_ERROR,
 	GDA_CONNECTION_OPEN_ERROR,
-	GDA_CONNECTION_STATEMENT_TYPE_ERROR
+	GDA_CONNECTION_STATEMENT_TYPE_ERROR,
+	GDA_CONNECTION_CANT_LOCK_ERROR,
+	GDA_CONNECTION_TASK_NOT_FOUND_ERROR,
+	GDA_CONNECTION_UNSUPPORTED_THREADS_ERROR
 } GdaConnectionError;
 #define GDA_CONNECTION_NONEXIST_DSN_ERROR GDA_CONNECTION_DSN_NOT_FOUND_ERROR
 
@@ -80,9 +83,37 @@ struct _GdaConnectionClass {
 	void (*_gda_reserved4) (void);
 };
 
+/**
+ * GdaConnectionOptions:
+ * @GDA_CONNECTION_OPTIONS_NONE: no specific aspect
+ * @GDA_CONNECTION_OPTIONS_READ_ONLY: this flag specifies that the connection to open should be in a read-only mode
+ *                                    (this policy is not correctly enforced at the moment)
+ * @GDA_CONNECTION_OPTIONS_THREAD_SAFE: this flag specifies that the connection to open will be used 
+ *                                     by several threads at once so it has to be thread safe
+ * @GDA_CONNECTION_OPTIONS_SQL_IDENTIFIERS_CASE_SENSITIVE: this flag specifies that SQL identifiers submitted as input
+ *                                    to Libgda have to keep their case sensitivity. 
+ *                                    
+ *
+ * Specifies some aspects of a connection when opening it.
+ *
+ * Additional information about the GDA_CONNECTION_OPTIONS_SQL_IDENTIFIERS_CASE_SENSITIVE flag:
+ * <itemizedlist>
+ *   <listitem><para>For example without this flag, if the table
+ *       name specified in a #GdaServerOperation to create a table is
+ *       <emphasis>MyTable</emphasis>, then usually the database will create a table named
+ *       <emphasis>mytable</emphasis>, whereas with this flag, the table will be created
+ *       as <emphasis>MyTable</emphasis> (note that in the end the database may still decide
+ *       to name the table <emphasis>mytable</emphasis> or differently if it can't do
+ *       otherwise).</para></listitem>
+ *   <listitem><para>Libgda will not apply this rule when parsing SQL code, the SQL code being parsed
+ *       has to be conform to the database it will be used with</para></listitem>
+ * </itemizedlist>
+ */
 typedef enum {
         GDA_CONNECTION_OPTIONS_NONE = 0,
-	GDA_CONNECTION_OPTIONS_READ_ONLY = 1 << 0
+	GDA_CONNECTION_OPTIONS_READ_ONLY = 1 << 0,
+	GDA_CONNECTION_OPTIONS_SQL_IDENTIFIERS_CASE_SENSITIVE = 1 << 1,
+	GDA_CONNECTION_OPTIONS_THREAD_SAFE = 1 << 2
 } GdaConnectionOptions;
 
 typedef enum {
@@ -165,9 +196,11 @@ GSList              *gda_connection_batch_execute        (GdaConnection *cnc,
 							  GdaBatch *batch, GdaSet *params,
 							  GdaStatementModelUsage model_usage, GError **error);
 
+gchar               *gda_connection_quote_sql_identifier (GdaConnection *cnc, const gchar *id);
 gchar               *gda_connection_statement_to_sql     (GdaConnection *cnc,
 							  GdaStatement *stmt, GdaSet *params, GdaStatementSqlFlag flags,
 							  GSList **params_used, GError **error);
+/* synchronous exec */
 gboolean             gda_connection_statement_prepare    (GdaConnection *cnc,
 							  GdaStatement *stmt, GError **error);
 GObject             *gda_connection_statement_execute    (GdaConnection *cnc, GdaStatement *stmt, GdaSet *params, 
@@ -184,6 +217,21 @@ GdaDataModel        *gda_connection_statement_execute_select_full (GdaConnection
 gint                 gda_connection_statement_execute_non_select (GdaConnection *cnc, GdaStatement *stmt,
 								  GdaSet *params, GdaSet **last_insert_row, GError **error);
 
+/* Async. execution */
+guint                gda_connection_async_statement_execute (GdaConnection *cnc, GdaStatement *stmt, GdaSet *params, 
+							     GdaStatementModelUsage model_usage, GType *col_types,
+							     gboolean need_last_insert_row, 
+							     GError **error);
+GObject             *gda_connection_async_fetch_result      (GdaConnection *cnc, guint task_id, GdaSet **last_insert_row, GError **error);
+gboolean             gda_connection_async_cancel            (GdaConnection *cnc, guint task_id, GError **error);
+
+
+/* repetitive statement */
+GSList             *gda_connection_repetitive_statement_execute (GdaConnection *cnc, GdaRepetitiveStatement *rstmt,
+								 GdaStatementModelUsage model_usage, GType *col_types,
+								 gboolean stop_on_error, GError **error);
+
+/* transactions */
 gboolean             gda_connection_begin_transaction    (GdaConnection *cnc, const gchar *name, 
 							  GdaTransactionIsolation level, GError **error);
 gboolean             gda_connection_commit_transaction   (GdaConnection *cnc, const gchar *name, GError **error);
