@@ -56,6 +56,9 @@ typedef enum {
 	GDA_SERVER_OPERATION_CREATE_VIEW,
 	GDA_SERVER_OPERATION_DROP_VIEW,
 
+	GDA_SERVER_OPERATION_COMMENT_TABLE,
+	GDA_SERVER_OPERATION_COMMENT_COLUMN,
+
 	GDA_SERVER_OPERATION_LAST
 } GdaServerOperationType;
 
