@@ -372,7 +372,7 @@ gda_set_new (GSList *holders)
  * gda_set_copy
  * @set: a #GdaSet object
  *
- * Creates a new #GdaSet object, opy of @set
+ * Creates a new #GdaSet object, copy of @set
  *
  * Returns: a new #GdaSet object
  */
@@ -403,7 +403,7 @@ gda_set_copy (GdaSet *set)
  * For each triplet (id, Glib type and value), 
  * the value must be of the correct type (gchar * if type is G_STRING, ...)
  *
- * Note that this function is a utility function and that anly a limited set of types are supported. Trying
+ * Note that this function is a utility function and that only a limited set of types are supported. Trying
  * to use an unsupported type will result in a warning, and the returned value holder holding a safe default
  * value.
  *
@@ -1275,12 +1275,6 @@ gda_set_is_valid (GdaSet *set, GError **error)
 		}
 	}
 
-	return _gda_set_validate (set, error);
-}
-
-gboolean
-_gda_set_validate (GdaSet *set, GError **error)
-{
 	/* signal the holder validate-set */
 	GError *lerror = NULL;
 #ifdef GDA_DEBUG_signal
@@ -1297,7 +1291,6 @@ _gda_set_validate (GdaSet *set, GError **error)
 	return TRUE;
 }
 
-
 /**
  * gda_set_get_holder
  * @set: a #GdaSet object
@@ -1311,7 +1304,7 @@ GdaHolder *
 gda_set_get_holder (GdaSet *set, const gchar *holder_id)
 {
 	g_return_val_if_fail (GDA_IS_SET (set), NULL);
-	g_return_val_if_fail (holder_id, NULL);
+	g_return_val_if_fail (set->priv, NULL);
 
 	return (GdaHolder *) g_hash_table_lookup (set->priv->holders_hash, holder_id);
 }
