@@ -49,7 +49,6 @@ struct _GdaSetNode {
 	GdaDataModel *source_model;  /* may be NULL */
 	gint          source_column; /* unused if @source_model is NULL */
 
-	/*< private >*/
 	/* Padding for future expansion */
 	gpointer      _gda_reserved1;
 	gpointer      _gda_reserved2;
@@ -59,7 +58,6 @@ struct _GdaSetGroup {
 	GSList       *nodes;       /* list of GdaSetNode, at least one entry */
 	GdaSetSource *nodes_source; /* if NULL, then @nodes contains exactly one entry */
 
-	/*< private >*/
 	/* Padding for future expansion */
 	gpointer      _gda_reserved1;
 	gpointer      _gda_reserved2;
@@ -69,7 +67,6 @@ struct _GdaSetSource {
 	GdaDataModel   *data_model;   /* Can't be NULL */
 	GSList         *nodes;        /* list of #GdaSetNode for which source_model == @data_model */
 
-	/*< private >*/
 	/* Padding for future expansion */
 	gpointer        _gda_reserved1;
 	gpointer        _gda_reserved2;
@@ -87,7 +84,7 @@ struct _GdaSet
 	GObject         object;
 	GdaSetPrivate  *priv;
 
-	/* public READ ONLY data */
+	/*< public >*/ 
 	GSList         *holders;   /* list of GdaHolder objects */
 	GSList         *nodes_list;   /* list of GdaSetNode */
         GSList         *sources_list; /* list of GdaSetSource */
@@ -135,10 +132,6 @@ GdaSetSource *gda_set_get_source_for_model     (GdaSet *set, GdaDataModel *model
 GdaSetSource *gda_set_get_source               (GdaSet *set, GdaHolder *holder);
 GdaSetGroup  *gda_set_get_group                (GdaSet *set, GdaHolder *holder);
 
-/* private */
-gboolean      _gda_set_validate                (GdaSet *set, GError **error);
-
-
 G_END_DECLS
 
 #endif
