@@ -713,14 +713,12 @@ default_render_value (const GValue *value, GdaSqlRenderingContext *context, GErr
  * Renders @stmt as an SQL statement, with some control on how it is rendered.
  *
  * If @cnc is not %NULL, then the rendered SQL will better be suited to be used by @cnc (in particular
- * it may include some SQL tweaks and/or proprietary extensions specific to the database engine used by @cnc):
- * in this case the result is similar to calling gda_connection_statement_to_sql().
+ * it may include some SQL tweaks and/or proprietary extensions specific to the database engine used by @cnc).
  *
  * Returns: a new string if no error occurred
  */
 gchar *
-gda_statement_to_sql_extended (GdaStatement *stmt, GdaConnection *cnc, GdaSet *params,
-			       GdaStatementSqlFlag flags, 
+gda_statement_to_sql_extended (GdaStatement *stmt, GdaConnection *cnc, GdaSet *params, GdaStatementSqlFlag flags, 
 			       GSList **params_used, GError **error)
 {
 	gchar *str;
@@ -733,13 +731,6 @@ gda_statement_to_sql_extended (GdaStatement *stmt, GdaConnection *cnc, GdaSet *p
 	context.params = params;
 	context.flags = flags;
 	if (cnc) {
-		GdaServerProvider *prov;
-		prov = gda_connection_get_provider (cnc);
-#define PROV_CLASS(provider) (GDA_SERVER_PROVIDER_CLASS (G_OBJECT_GET_CLASS (provider)))
-		if (prov && PROV_CLASS (prov)->statement_to_sql)
-			return (PROV_CLASS (prov)->statement_to_sql) (prov, 
-								      cnc, stmt, params, flags, 
-								      params_used, error);
 		context.cnc = cnc;
 		context.provider = gda_connection_get_provider (cnc);
 	}
@@ -793,7 +784,6 @@ default_render_insert (GdaSqlStatementInsert *stmt, GdaSqlRenderingContext *cont
 	GString *string;
 	gchar *str;
 	GSList *list;
-	gboolean pretty = context->flags & GDA_STATEMENT_SQL_PRETTY;
 
 	g_return_val_if_fail (stmt, NULL);
 	g_return_val_if_fail (GDA_SQL_ANY_PART (stmt)->type == GDA_SQL_ANY_STMT_INSERT, NULL);
@@ -827,10 +817,7 @@ default_render_insert (GdaSqlStatementInsert *stmt, GdaSqlRenderingContext *cont
 
 	/* values */
 	if (stmt->select) {
-		if (pretty)
-			g_string_append_c (string, '\n');
-		else
-			g_string_append_c (string, ' ');
+		g_string_append_c (string, ' ');
 		str = context->render_select (GDA_SQL_ANY_PART (stmt->select), context, error);
 		if (!str) goto err;
 		g_string_append (string, str);
@@ -839,12 +826,8 @@ default_render_insert (GdaSqlStatementInsert *stmt, GdaSqlRenderingContext *cont
 	else {
 		for (list = stmt->values_list; list; list = list->next) {
 			GSList *rlist;
-			if (list == stmt->values_list) {
-				if (pretty)
-					g_string_append (string, "\nVALUES");
-				else
-					g_string_append (string, " VALUES");
-			}
+			if (list == stmt->values_list)
+				g_string_append (string, " VALUES");
 			else
 				g_string_append_c (string, ',');
 			for (rlist = (GSList*) list->data; rlist; rlist = rlist->next) {
@@ -854,8 +837,6 @@ default_render_insert (GdaSqlStatementInsert *stmt, GdaSqlRenderingContext *cont
 					g_string_append (string, ", ");
 				str = context->render_expr ((GdaSqlExpr*) rlist->data, context, NULL, NULL, error);
 				if (!str) goto err;
-				if (pretty && (rlist != (GSList*) list->data))
-					g_string_append (string, "\n\t");
 				g_string_append (string, str);
 				g_free (str);
 			}
@@ -914,7 +895,6 @@ default_render_update (GdaSqlStatementUpdate *stmt, GdaSqlRenderingContext *cont
 	GString *string;
 	gchar *str;
 	GSList *flist, *elist;
-	gboolean pretty = context->flags & GDA_STATEMENT_SQL_PRETTY;
 
 	g_return_val_if_fail (stmt, NULL);
 	g_return_val_if_fail (GDA_SQL_ANY_PART (stmt)->type == GDA_SQL_ANY_STMT_UPDATE, NULL);
@@ -931,18 +911,10 @@ default_render_update (GdaSqlStatementUpdate *stmt, GdaSqlRenderingContext *cont
 	g_free (str);
 
 	/* columns set */
-	if (pretty)
-		g_string_append (string, "\nSET ");
-	else
-		g_string_append (string, " SET ");
-	for (flist = stmt->fields_list, elist = stmt->expr_list;
-	     flist && elist;
-	     flist = flist->next, elist = elist->next) {
-		if (flist != stmt->fields_list) {
+	g_string_append (string, " SET ");
+	for (flist = stmt->fields_list, elist = stmt->expr_list; flist && elist; flist = flist->next, elist = elist->next) {
+		if (flist != stmt->fields_list)
 			g_string_append (string, ", ");
-			if (pretty)
-				g_string_append (string, "\n\t");
-		}
 		str = context->render_field (GDA_SQL_ANY_PART (flist->data), context, error);
 		if (!str) goto err;
 		g_string_append (string, str);
@@ -956,10 +928,7 @@ default_render_update (GdaSqlStatementUpdate *stmt, GdaSqlRenderingContext *cont
 
 	/* cond */
 	if (stmt->cond) {
-		if (pretty)
-			g_string_append (string, "\nWHERE ");
-		else
-			g_string_append (string, " WHERE ");
+		g_string_append (string, " WHERE ");
 		str = context->render_expr (stmt->cond, context, NULL, NULL, error);
 		if (!str) goto err;
 		g_string_append (string, str);
@@ -1048,7 +1017,6 @@ default_render_select (GdaSqlStatementSelect *stmt, GdaSqlRenderingContext *cont
 	GString *string;
 	gchar *str;
 	GSList *list;
-	gboolean pretty = context->flags & GDA_STATEMENT_SQL_PRETTY;
 
 	g_return_val_if_fail (stmt, NULL);
 	g_return_val_if_fail (GDA_SQL_ANY_PART (stmt)->type == GDA_SQL_ANY_STMT_SELECT, NULL);
@@ -1065,8 +1033,6 @@ default_render_select (GdaSqlStatementSelect *stmt, GdaSqlRenderingContext *cont
 			g_string_append_c (string, ' ');
 			g_free (str);
 		}
-		if (pretty)
-			g_string_append_c (string, '\n');
 	}
 	
 	/* selected expressions */
@@ -1075,8 +1041,6 @@ default_render_select (GdaSqlStatementSelect *stmt, GdaSqlRenderingContext *cont
 		if (!str) goto err;
 		if (list != stmt->expr_list)
 			g_string_append (string, ", ");
-		if (pretty)
-			g_string_append (string, "\n\t");
 		g_string_append (string, str);
 		g_free (str);
 	}
@@ -1085,20 +1049,14 @@ default_render_select (GdaSqlStatementSelect *stmt, GdaSqlRenderingContext *cont
 	if (stmt->from) {
 		str = context->render_select_from (GDA_SQL_ANY_PART (stmt->from), context, error);
 		if (!str) goto err;
-		if (pretty)
-			g_string_append_c (string, '\n');
-		else
-			g_string_append_c (string, ' ');
+		g_string_append_c (string, ' ');
 		g_string_append (string, str);
 		g_free (str);
 	}
 
 	/* WHERE */
 	if (stmt->where_cond) {
-		if (pretty)
-			g_string_append (string, "\nWHERE ");
-		else
-			g_string_append (string, " WHERE ");
+		g_string_append (string, " WHERE ");
 		str = context->render_expr (stmt->where_cond, context, NULL, NULL, error);
 		if (!str) goto err;
 		g_string_append (string, str);
@@ -1111,22 +1069,15 @@ default_render_select (GdaSqlStatementSelect *stmt, GdaSqlRenderingContext *cont
 		if (!str) goto err;
 		if (list != stmt->group_by)
 			g_string_append (string, ", ");
-		else {
-			if (pretty)
-				g_string_append (string, "\nGROUP BY ");
-			else
-				g_string_append (string, " GROUP BY ");
-		}
+		else
+			g_string_append (string, " GROUP BY ");
 		g_string_append (string, str);
 		g_free (str);
 	}
 
 	/* HAVING */
 	if (stmt->having_cond) {
-		if (pretty)
-			g_string_append (string, "\nHAVING ");
-		else
-			g_string_append (string, " HAVING ");
+		g_string_append (string, " HAVING ");
 		str = context->render_expr (stmt->having_cond, context, NULL, NULL, error);
 		if (!str) goto err;
 		g_string_append (string, str);
@@ -1139,12 +1090,8 @@ default_render_select (GdaSqlStatementSelect *stmt, GdaSqlRenderingContext *cont
 		if (!str) goto err;
 		if (list != stmt->order_by)
 			g_string_append (string, ", ");
-		else {
-			if (pretty)
-				g_string_append (string, "\nORDER BY ");
-			else
-				g_string_append (string, " ORDER BY ");
-		}
+		else
+			g_string_append (string, " ORDER BY ");
 		g_string_append (string, str);
 		g_free (str);
 	}
@@ -1421,16 +1368,15 @@ default_render_expr (GdaSqlExpr *expr, GdaSqlRenderingContext *context, gboolean
 	}
 	else if (expr->select) {
 		gchar *str1;
-		str1 = context->render_select (GDA_SQL_ANY_PART (expr->select), context, error);
-		if (!str1) goto err;
-
-		if (! GDA_SQL_ANY_PART (expr)->parent ||
-		    (GDA_SQL_ANY_PART (expr)->parent->type != GDA_SQL_ANY_SQL_FUNCTION)) {
-			str = g_strdup_printf ("(%s)", str1);
-			g_free (str1);
-		}
+		if (GDA_SQL_ANY_PART (expr->select)->type == GDA_SQL_ANY_STMT_SELECT)
+			str1 = context->render_select (GDA_SQL_ANY_PART (expr->select), context, error);
+		else if (GDA_SQL_ANY_PART (expr->select)->type == GDA_SQL_ANY_STMT_COMPOUND)
+			str1 = context->render_compound (GDA_SQL_ANY_PART (expr->select), context, error);
 		else
-			str = str1;
+			g_assert_not_reached ();
+		if (!str1) goto err;
+		str = g_strdup_printf ("(%s)", str1);
+		g_free (str1);
 	}
 	else if (expr->case_s) {
 		str = context->render_case (GDA_SQL_ANY_PART (expr->case_s), context, error);
@@ -1531,7 +1477,7 @@ default_render_function (GdaSqlFunction *func, GdaSqlRenderingContext *context,
 	if (!gda_sql_any_part_check_structure (GDA_SQL_ANY_PART (func), error)) return NULL;
 
 	string = g_string_new (func->function_name);
-	g_string_append (string, " (");
+	g_string_append_c (string, '(');
 	for (list = func->args_list; list; list = list->next) {
 		if (list != func->args_list)
 			g_string_append (string, ", ");
@@ -1885,7 +1831,6 @@ default_render_select_join (GdaSqlSelectJoin *join, GdaSqlRenderingContext *cont
 {
 	GString *string;
 	gchar *str;
-	gboolean pretty = context->flags & GDA_STATEMENT_SQL_PRETTY;
 
 	g_return_val_if_fail (join, NULL);
 	g_return_val_if_fail (GDA_SQL_ANY_PART (join)->type == GDA_SQL_ANY_SQL_SELECT_JOIN, NULL);
@@ -1898,40 +1843,22 @@ default_render_select_join (GdaSqlSelectJoin *join, GdaSqlRenderingContext *cont
 
 	switch (join->type) {
 	case GDA_SQL_SELECT_JOIN_CROSS:
-		if (pretty)
-			string = g_string_new (",\n\t");
-		else
-			string = g_string_new (",");
+		string = g_string_new (",");
 		break;
         case GDA_SQL_SELECT_JOIN_NATURAL:
-		if (pretty)
-			string = g_string_new ("\n\tNATURAL JOIN");
-		else
-			string = g_string_new ("NATURAL JOIN");
+		string = g_string_new ("NATURAL JOIN");
 		break;
         case GDA_SQL_SELECT_JOIN_INNER:
-		if (pretty)
-			string = g_string_new ("\n\tINNER JOIN");
-		else
-			string = g_string_new ("INNER JOIN");
+		string = g_string_new ("INNER JOIN");
 		break;
         case GDA_SQL_SELECT_JOIN_LEFT:
-		if (pretty)
-			string = g_string_new ("\n\tLEFT JOIN");
-		else
-			string = g_string_new ("LEFT JOIN");
+		string = g_string_new ("LEFT JOIN");
 		break;
         case GDA_SQL_SELECT_JOIN_RIGHT:
-		if (pretty)
-			string = g_string_new ("\n\tRIGHT JOIN");
-		else
-			string = g_string_new ("RIGHT JOIN");
+		string = g_string_new ("RIGHT JOIN");
 		break;
         case GDA_SQL_SELECT_JOIN_FULL:
-		if (pretty)
-			string = g_string_new ("\n\tFULL JOIN");
-		else
-			string = g_string_new ("FULL JOIN");
+		string = g_string_new ("FULL JOIN");
 		break;
 	default:
 		g_assert_not_reached ();
@@ -1953,7 +1880,6 @@ default_render_select_join (GdaSqlSelectJoin *join, GdaSqlRenderingContext *cont
 	}
 	str = context->render_select_target (GDA_SQL_ANY_PART (target), context, error);
 	if (!str) goto err;
-
 	g_string_append_c (string, ' ');
 	g_string_append (string, str);
 	g_free (str);
@@ -2007,7 +1933,6 @@ default_render_select_from (GdaSqlSelectFrom *from, GdaSqlRenderingContext *cont
 	gchar *str;
 	GSList *tlist;
 	gint i;
-	gboolean pretty = context->flags & GDA_STATEMENT_SQL_PRETTY;
 
 	g_return_val_if_fail (from, NULL);
 	g_return_val_if_fail (GDA_SQL_ANY_PART (from)->type == GDA_SQL_ANY_SQL_SELECT_FROM, NULL);
@@ -2024,20 +1949,14 @@ default_render_select_from (GdaSqlSelectFrom *from, GdaSqlRenderingContext *cont
 		if (join) {
 			str = context->render_select_join (GDA_SQL_ANY_PART (join), context, error);
 			if (!str) goto err;
-			if (!pretty)
-				g_string_append_c (string, ' ');
+			g_string_append_c (string, ' ');
 			g_string_append (string, str);
 			g_free (str);
-			if (!pretty)
-				g_string_append_c (string, ' ');
+			g_string_append_c (string, ' ');
 		}
 		else {
-			if (tlist != from->targets) {
-				if (pretty)
-					g_string_append (string, ",\n\t");
-				else
-					g_string_append (string, ", ");
-			}
+			if (tlist != from->targets)
+				g_string_append (string, ", ");
 			str = context->render_select_target (GDA_SQL_ANY_PART (tlist->data), context, error);
 			if (!str) goto err;
 			g_string_append (string, str);
