@@ -85,10 +85,6 @@ gda_g_type_to_string (GType type)
 		return "timestamp";
 	else if (type == G_TYPE_BOOLEAN)
 		return "boolean";
-	else if (type == GDA_TYPE_BLOB)
-		return "blob";
-	else if (type == GDA_TYPE_BINARY)
-		return "binary";
 	else 
 		return g_type_name (type);
 }
@@ -108,12 +104,10 @@ gda_g_type_to_string (GType type)
  *   <listitem><para>"time" for GDA_TYPE_TIME</para></listitem>
  *   <listitem><para>"timestamp" for GDA_TYPE_TIMESTAMP</para></listitem>
  *   <listitem><para>"boolean" for G_TYPE_BOOLEAN</para></listitem>
- *   <listitem><para>"blob" for GDA_TYPE_BLOB</para></listitem>
- *   <listitem><para>"binary" for GDA_TYPE_BINARY</para></listitem>
  *   <listitem><para>"null" for GDA_TYPE_NULL</para></listitem>
  * </itemizedlist>
  *
- * Returns: the #GType represented by the given @str, or #G_TYPE_INVALID if not found
+ * Returns: the #GType represented by the given @str.
  */
 GType
 gda_g_type_from_string (const gchar *str)
@@ -135,10 +129,6 @@ gda_g_type_from_string (const gchar *str)
 			type = GDA_TYPE_TIMESTAMP;
 		else if (!strcmp (str, "boolean"))
                         type = G_TYPE_BOOLEAN;
-		else if (!strcmp (str, "blob"))
-			type = GDA_TYPE_BLOB;
-		else if (!strcmp (str, "binary"))
-			type = GDA_TYPE_BINARY;
 		else if (!strcmp (str, "null"))
 			type = GDA_TYPE_NULL;
 		else
@@ -154,7 +144,7 @@ gda_g_type_from_string (const gchar *str)
  * @string: string to escape
  *
  * Escapes @string to make it understandable by a DBMS. The escape method is very common and replaces any
- * occurence of "'" with "''" and "\" with "\\"
+ * occurrence of "'" with "''" and "\" with "\\"
  *
  * Returns: a new string
  */
@@ -207,8 +197,8 @@ gda_default_escape_string (const gchar *string)
  * gda_default_unescape_string
  * @string: string to unescape
  *
- * Do the reverse of gda_default_escape_string(): transforms any "''" into "'", any
- * "\\" into "\" and any "\'" into "'". 
+ * Do the reverse of gda_default_escape_string(): transforms any "\'" into "'" and any
+ * "\\" into "\". 
  *
  * Returns: a new unescaped string, or %NULL in an error was found in @string
  */
@@ -589,7 +579,6 @@ gda_utility_holder_load_attributes (GdaHolder *holder, xmlNodePtr node, GSList *
 				}
 			}
 		}
-		g_free (source);
 	}
 
 	/* specified value */
@@ -706,7 +695,7 @@ gda_text_to_alphanum (const gchar *text)
  *
  * Does the opposite of gda_text_to_alphanum(), in the same string 
  *
- * Returns: @text if conversion succedded or %NULL if an error occurred
+ * Returns: @text if conversion succeeded or %NULL if an error occurred
  */
 gchar *
 gda_alphanum_to_text (gchar *text)
@@ -858,7 +847,6 @@ gda_compute_unique_table_row_condition_with_cnc (GdaConnection *cnc, GdaSqlState
 				GdaSqlOperation *op;
 				GdaSqlExpr *opexpr;
 				GdaSqlParamSpec *pspec;
-				gchar *str;
 
 				/* equal condition */
 				if (and_cond) {
@@ -873,6 +861,7 @@ gda_compute_unique_table_row_condition_with_cnc (GdaConnection *cnc, GdaSqlState
 				}
 				op->operator_type = GDA_SQL_OPERATOR_TYPE_EQ;
 				/* left operand */
+				gchar *str;
 				opexpr = gda_sql_expr_new (GDA_SQL_ANY_PART (op));
 				str = gda_sql_identifier_quote (tcol->column_name, cnc, NULL, FALSE, FALSE);
 				g_value_take_string (opexpr->value = gda_value_new (G_TYPE_STRING), str);
@@ -955,8 +944,6 @@ gda_compute_dml_statements (GdaConnection *cnc, GdaStatement *select_stmt, gbool
         GdaSqlStatement *sql_dst = NULL;
         GdaSqlStatementDelete *dst = NULL;
 
-	gchar *tmp;
-
 	g_return_val_if_fail (GDA_IS_CONNECTION (cnc), FALSE);
 	g_return_val_if_fail (GDA_IS_STATEMENT (select_stmt), FALSE);
 	g_return_val_if_fail (gda_statement_get_statement_type (select_stmt) == GDA_SQL_STATEMENT_SELECT, FALSE);
@@ -983,6 +970,7 @@ gda_compute_dml_statements (GdaConnection *cnc, GdaStatement *select_stmt, gbool
 	target = (GdaSqlSelectTarget*) stsel->from->targets->data;
 	
 	/* actual statement structure's computation */
+	gchar *tmp;
 	tmp = gda_sql_identifier_quote (target->table_name, cnc, NULL, FALSE, FALSE);
 	if (insert_stmt) {
 		sql_ist = gda_sql_statement_new (GDA_SQL_STATEMENT_INSERT);
@@ -990,7 +978,7 @@ gda_compute_dml_statements (GdaConnection *cnc, GdaStatement *select_stmt, gbool
 		g_assert (GDA_SQL_ANY_PART (ist)->type == GDA_SQL_ANY_STMT_INSERT);
 
 		ist->table = gda_sql_table_new (GDA_SQL_ANY_PART (ist));
-		ist->table->table_name = g_strdup (tmp);
+		ist->table->table_name = g_strdup ((gchar *) target->table_name);
 	}
 	
 	if (update_stmt) {
@@ -1005,11 +993,9 @@ gda_compute_dml_statements (GdaConnection *cnc, GdaStatement *select_stmt, gbool
 									     require_pk, error);
 		if (!ust->cond) {
 			retval = FALSE;
-			*update_stmt = NULL;
-			update_stmt = NULL; /* don't try anymore to build UPDATE statement */
+			goto cleanup;
 		}
-		else
-			GDA_SQL_ANY_PART (ust->cond)->parent = GDA_SQL_ANY_PART (ust);
+		GDA_SQL_ANY_PART (ust->cond)->parent = GDA_SQL_ANY_PART (ust);
 	}
         
 	if (delete_stmt) {
@@ -1019,19 +1005,14 @@ gda_compute_dml_statements (GdaConnection *cnc, GdaStatement *select_stmt, gbool
 
 		dst->table = gda_sql_table_new (GDA_SQL_ANY_PART (dst));
 		dst->table->table_name = g_strdup (tmp);
-		if (update_stmt && ust->cond)
-			dst->cond = gda_sql_expr_copy (ust->cond);
-		else
-			dst->cond = gda_compute_unique_table_row_condition_with_cnc (cnc, stsel, 
+		dst->cond = gda_compute_unique_table_row_condition_with_cnc (cnc, stsel, 
 									     GDA_META_TABLE (target->validity_meta_object),
 									     require_pk, error);
 		if (!dst->cond) {
 			retval = FALSE;
-			*delete_stmt = NULL;
-			delete_stmt = NULL; /* don't try anymore to build DELETE statement */
+			goto cleanup;
 		}
-		else
-			GDA_SQL_ANY_PART (dst->cond)->parent = GDA_SQL_ANY_PART (dst);
+		GDA_SQL_ANY_PART (dst->cond)->parent = GDA_SQL_ANY_PART (dst);
 	}
 	g_free (tmp);
 
@@ -1058,16 +1039,15 @@ gda_compute_dml_statements (GdaConnection *cnc, GdaStatement *select_stmt, gbool
 		if (insert_stmt) {
 			GdaSqlField *field;
 			field = gda_sql_field_new (GDA_SQL_ANY_PART (ist));
-			field->field_name = g_strdup (str);
+			field->field_name = g_strdup (selfield->field_name);
 			ist->fields_list = g_slist_append (ist->fields_list, field);
 		}
 		if (update_stmt) {
 			GdaSqlField *field;
 			field = gda_sql_field_new (GDA_SQL_ANY_PART (ust));
-			field->field_name = g_strdup (str);
+			field->field_name = g_strdup (selfield->field_name);
 			ust->fields_list = g_slist_append (ust->fields_list, field);
 		}
-		g_free (str);
 
 		/* parameter for the inserted value */
 		GdaSqlExpr *expr;
@@ -1104,11 +1084,10 @@ gda_compute_dml_statements (GdaConnection *cnc, GdaStatement *select_stmt, gbool
 			g_set_error (error, GDA_SQL_ERROR, GDA_SQL_STRUCTURE_CONTENTS_ERROR,
 				     "%s", _("Could not compute any field to insert into"));
 			retval = FALSE;
+			goto cleanup;
 		}
-		else {
-			ist->values_list = g_slist_append (NULL, insert_values_list);
-			ret_insert = g_object_new (GDA_TYPE_STATEMENT, "structure", sql_ist, NULL);
-		}
+		ist->values_list = g_slist_append (NULL, insert_values_list);
+		ret_insert = g_object_new (GDA_TYPE_STATEMENT, "structure", sql_ist, NULL);
 	}
 	if (update_stmt)
 		ret_update = g_object_new (GDA_TYPE_STATEMENT, "structure", sql_ust, NULL);
@@ -1140,7 +1119,7 @@ gda_compute_dml_statements (GdaConnection *cnc, GdaStatement *select_stmt, gbool
  *
  * Computes a SELECT statement which selects all the rows the @update_stmt would update. Beware
  * however that this GdaSqlStatement does not select anything (ie it would be rendered as "SELECT FROM ... WHERE ...")
- * and before being useable, one needs to add some fields to actually select.
+ * and before being usable, one needs to add some fields to actually select.
  *
  * Returns; a new #GdaStatement if no error occurred, or %NULL otherwise
  */
@@ -1175,8 +1154,7 @@ gda_compute_select_statement_from_update (GdaStatement *update_stmt, GError **er
 	target = gda_sql_select_target_new (GDA_SQL_ANY_PART (sst->from));
 	sst->from->targets = g_slist_prepend (NULL, target);
 	target->expr = gda_sql_expr_new (GDA_SQL_ANY_PART (target));
-	g_value_set_string ((target->expr->value = gda_value_new (G_TYPE_STRING)),
-			    ust->table->table_name);
+	g_value_set_string ((target->expr->value = gda_value_new (G_TYPE_STRING)), ust->table->table_name);
 
 	/* WHERE */
 	sst->where_cond = gda_sql_expr_copy (ust->cond);
@@ -1319,12 +1297,6 @@ prepare_sql_identifier_for_compare (gchar *str)
 	}
 }
 
-static gint
-cmp_func (gconstpointer a, gconstpointer b)
-{
-	return g_strcmp0 (*((gchar**) a), *((gchar**) b));
-}
-
 /**
  * gda_completion_list_get
  * @cnc: a #GdaConnection object
@@ -1348,8 +1320,6 @@ gda_completion_list_get (GdaConnection *cnc, const gchar *sql, gint start, gint
 	if (!cnc) 
 		return NULL;
 	g_return_val_if_fail (GDA_IS_CONNECTION (cnc), NULL);
-	if (!sql || !(*sql))
-		return NULL;
 	if (end < start)
 		return NULL;
 
@@ -1502,7 +1472,7 @@ gda_completion_list_get (GdaConnection *cnc, const gchar *sql, gint start, gint
 						
 						g_object_unref (m2);
 					}
-					g_free (str);
+					free (str);
 				}
 			}
 		}
@@ -1536,23 +1506,6 @@ gda_completion_list_get (GdaConnection *cnc, const gchar *sql, gint start, gint
 	g_free (text);
 	if (compl) {
 		if (compl->len >= 1) {
-			/* sort */
-			gint i;
-			g_array_sort (compl, cmp_func);
-
-			/* remove duplicates if any */
-			for (i = 1; i < compl->len; ) {
-				gchar *current, *before;
-				current = g_array_index (compl, gchar*, i);
-				before = g_array_index (compl, gchar*, i - 1);
-				if (!strcmp (current, before)) {
-					g_free (current);
-					g_array_remove_index (compl, i);
-				}
-				else
-					i++;
-			}
-
 			gchar **ptr;
 			ptr = (gchar**) compl->data;
 			g_array_free (compl, FALSE);
@@ -1598,7 +1551,7 @@ concat_ident (const char *prefix, const gchar *ident)
  *
  * For example the <![CDATA["test.\"ATable\""]]> string will result in the array: <![CDATA[{"test", "\"ATable\"", NULL}]]>
  *
- * Returns: a new %NULL-terminated array of strings, or NULL (use g_strfreev() to free the returned array)
+ * Returns: a new array of strings, or NULL (use g_strfreev() to free the returned array)
  */
 gchar **
 gda_sql_identifier_split (const gchar *id)
@@ -1823,9 +1776,6 @@ gda_sql_identifier_quote (const gchar *id, GdaConnection *cnc, GdaServerProvider
 			prov = gda_connection_get_provider (cnc);
 	}
 
-	if ((*id == '*') && (! id [1]))
-	    return g_strdup (id);
-
 	if (prov && PROV_CLASS (prov)->identifier_quote)
 		return PROV_CLASS (prov)->identifier_quote (prov, cnc, id,
 							    for_meta_store, force_quotes);
@@ -2096,7 +2046,7 @@ gda_rfc1738_decode (gchar *string)
  *
  * Extract the DSN, username and password from @string. in @string, the various parts are strings
  * which are expected to be encoded using an RFC 1738 compliant encoding. If they are specified, 
- * the returned username and password strings are correclty decoded.
+ * the returned username and password strings are correctly decoded.
  *
  * @out_username and @out_password may be set to %NULL depending on @string's format.
  */
@@ -2147,26 +2097,6 @@ gda_dsn_split (const gchar *string, gchar **out_dsn, gchar **out_username, gchar
  * in @string, the various parts are strings
  * which are expected to be encoded using an RFC 1738 compliant encoding. If they are specified, 
  * the returned provider, username and password strings are correctly decoded.
- *
- * For example all the following connection strings:
- * <programlisting><![CDATA[
-PostgreSQL://meme:pass@DB_NAME=mydb;HOST=server
-PostgreSQL://meme@DB_NAME=mydb;HOST=server;PASSWORD=pass
-PostgreSQL://meme@DB_NAME=mydb;PASSWORD=pass;HOST=server
-PostgreSQL://meme@PASSWORD=pass;DB_NAME=mydb;HOST=server
-PostgreSQL://DB_NAME=mydb;HOST=server;USERNAME=meme;PASSWORD=pass
-PostgreSQL://DB_NAME=mydb;HOST=server;PASSWORD=pass;USERNAME=meme
-PostgreSQL://DB_NAME=mydb;USERNAME=meme;PASSWORD=pass;HOST=server
-PostgreSQL://PASSWORD=pass;USERNAME=meme;DB_NAME=mydb;HOST=server
-PostgreSQL://:pass@USERNAME=meme;DB_NAME=mydb;HOST=server
-PostgreSQL://:pass@DB_NAME=mydb;HOST=server;USERNAME=meme]]></programlisting>
- *
- * will return the following new strings (double quotes added here to delimit strings):
- * <programlisting><![CDATA[
-out_cnc_params: "DB_NAME=mydb;HOST=server"
-out_provider: "PostgreSQL"
-out_username: "meme"
-out_password: "pass"]]></programlisting>
  */
 void
 gda_connection_string_split (const gchar *string, gchar **out_cnc_params, gchar **out_provider, 
@@ -2215,46 +2145,6 @@ gda_connection_string_split (const gchar *string, gchar **out_cnc_params, gchar
 	if (!*out_cnc_params)
 		*out_cnc_params = g_strdup (ap);
 
-	if (*out_cnc_params) {
-		gchar *pos;
-
-		pos = g_strrstr (*out_cnc_params, "USERNAME=");
-		if (pos) {
-			for (ptr = pos + 9; ptr && *ptr != '\0' && *ptr != ';'; ptr++);
-			if (ptr != pos + 9)
-				*out_username = g_strndup (pos + 9, ptr - (pos + 9));
-			gchar *tmp;
-			gint lastpos;
-			tmp = g_strndup (*out_cnc_params, pos - *out_cnc_params);
-			*out_cnc_params = g_strconcat (tmp,
-						       (ptr ? (ptr + 1 ? ptr + 1 : ptr) : ""),
-						       NULL);
-			g_free (tmp);
-			tmp = *out_cnc_params;
-			lastpos = strlen(tmp) - 1;
-			if (tmp [lastpos] == ';')
-				tmp [lastpos] = 0;
-		}
-		
-		pos = g_strrstr (*out_cnc_params, "PASSWORD=");
-		if (pos) {
-			for (ptr = pos + 9; ptr && *ptr != '\0' && *ptr != ';'; ptr++);
-			if (ptr != pos + 9)
-				*out_password = g_strndup (pos + 9, ptr - (pos + 9));
-			gchar *tmp;
-			gint lastpos;
-			tmp = g_strndup (*out_cnc_params, pos - *out_cnc_params);
-			*out_cnc_params = g_strconcat (tmp,
-						       (ptr ? (ptr + 1 ? ptr + 1 : ptr) : ""),
-						       NULL);
-			g_free (tmp);
-			tmp = *out_cnc_params;
-			lastpos = strlen(tmp) - 1;
-			if (tmp [lastpos] == ';')
-				tmp [lastpos] = 0;
-		}
-	}
-
 	/* RFC 1738 decode provider, username and password strings */
 	gda_rfc1738_decode (*out_provider);
 	gda_rfc1738_decode (*out_username);
