@@ -442,11 +442,9 @@ gda_blob_free (gpointer boxed)
 	GdaBlob *blob = (GdaBlob*) boxed;
 	
 	g_return_if_fail (blob);
-
-	if (blob->op) {
+		
+	if (blob->op)
 		g_object_unref (blob->op);
-		blob->op = NULL;
-	}
 	gda_binary_free ((GdaBinary *) blob);
 }
 
@@ -466,7 +464,8 @@ gda_blob_set_op (GdaBlob *blob, GdaBlobOp *op)
 	}
 	if (op) {
 		g_return_if_fail (GDA_IS_BLOB_OP (op));
-		blob->op = g_object_ref (op);
+		blob->op = op;
+		g_object_ref (op);
 	}
 }
 
@@ -1750,7 +1749,7 @@ gda_value_set_timestamp (GValue *value, const GdaTimestamp *val)
  *
  * Returns: %TRUE if the value has been converted to @type from
  * its string representation; it not means that the value is converted 
- * successfully, just that the transformation is avairable. %FALSE otherwise.
+ * successfully, just that the transformation is available. %FALSE otherwise.
  */
 gboolean
 gda_value_set_from_string (GValue *value, 
@@ -2490,13 +2489,6 @@ gda_ushort_get_type (void) {
  * where "xyz" is the octal representation of the byte, and the '\' (backslash) character
  * is converted to "\\".
  *
- * Note that the backslash and newline characters are considered as printable characters and
- * will not be represented by the "\xyz" representation.
- *
- * Use this function to get a representation as much readable by humans as possible of a binary
- * chunk. Note that this function is internally called when transforming a binary value to
- * a string for example when using g_value_transform() or gda_value_stringify().
- *
  * Returns: a new string from @bin
  */
 gchar *
