@@ -87,12 +87,12 @@ _remove_quotes (gchar *str)
 
         total = strlen (str);
         if (str[total-1] == delim) {
-		/* string is correclty terminated by a double quote */
+		/* string is correctly terminated by a double quote */
 		g_memmove (str, str+1, total-2);
 		total -=2;
 	}
 	else {
-		/* string is _not_ correclty terminated by a double quote */
+		/* string is _not_ correctly terminated by a double quote */
 		g_memmove (str, str+1, total-1);
 		total -=1;
 	}
@@ -145,6 +145,8 @@ _remove_quotes (gchar *str)
  * function to tell if an identifier needs to be quoted.
  *
  * Returns: a new string
+ *
+ * Deprecated: 4.0.3: Use gda_sql_identifier_quote() instead.
  */
 gchar *
 gda_sql_identifier_add_quotes (const gchar *str)
@@ -268,12 +270,17 @@ _string_is_identifier (const gchar *str)
 
 	if (!str || !(*str)) 
 		return FALSE;
-	for (ptr = *str == '"' ? str + 1 : str; 
-	     IdChar(*ptr) || (*ptr == '*') || (*ptr == '.') || ((*ptr == '"') && ptr[1] == 0); 
+	if ((*str == '"') || (*str == '`'))
+		ptr = str + 1;
+	else
+		ptr = str;
+	for (; 
+	     IdChar(*ptr) || (*ptr == '*') || (*ptr == '.') || (((*ptr == '"') || (*ptr == '`')) && ptr[1] == 0); 
 	     ptr++);
 	if (*ptr) 
 		return FALSE;
-	if ((*str == '"') && (ptr[-1] == '"'))
+	if (((*str == '"') && (ptr[-1] == '"')) ||
+	    ((*str == '`') && (ptr[-1] == '`')))
 		return TRUE;
 
 	/* @str is composed only of character that can be used in an identifier */
@@ -291,16 +298,47 @@ _string_is_identifier (const gchar *str)
  * Tells if @str needs to be quoted before using it in an SQL statement. To actually add quotes,
  * use gda_sql_identifier_add_quotes().
  *
+ * To determine if quotes are needed: the following rules are applied:
+ * <itemizedlist>
+ *  <listitem><para>If the 1st character is a digit, then %TRUE is returned</para></listitem>
+ *  <listitem><para>If there are mixed lower and upper case letters, then %TRUE is returned</para></listitem>
+ *  <listitem><para>If there are other characters than digits, letters and the '_', '$' and '#', then %TRUE is returned</para></listitem>
+ *  <listitem><para>Otherwise %FALSE is returned</para></listitem>
+ * </itemizedlist>
+ *
  * Returns: TRUE if @str needs some quotes
+ *
+ * Deprecated: 4.0.3: Not needed anymore because of the gda_sql_identifier_quote()
  */
 gboolean
 gda_sql_identifier_needs_quotes (const gchar *str)
 {
 	const gchar *ptr;
+	gchar icase = 0;
 
 	g_return_val_if_fail (str, FALSE);
 	for (ptr = str; *ptr; ptr++) {
-		if (*ptr != g_ascii_tolower (*ptr))
+		/* quote if 1st char is a number */
+		if ((*ptr <= '9') && (*ptr >= '0')) {
+			if (ptr == str)
+				return TRUE;
+			continue;
+		}
+		if ((*ptr >= 'A') && (*ptr <= 'Z')) {
+			if (icase == 0) /* first alpha char encountered */
+				icase = 'U';
+			else if (icase == 'L') /* @str has mixed case */
+				return TRUE;
+			continue;
+		}
+		if ((*ptr >= 'a') && (*ptr <= 'z')) {
+			if (icase == 0) /* first alpha char encountered */
+				icase = 'L';
+			else if (icase == 'U')
+				return TRUE; /* @str has mixed case */
+			continue;
+		}
+		if ((*ptr != '$') && (*ptr != '_') && (*ptr != '#'))
 			return TRUE;
 	}
 	return FALSE;
@@ -324,6 +362,8 @@ gda_sql_identifier_needs_quotes (const gchar *str)
  * WARNING: @str must NOT be a composed identifier (&lt;part1&gt;."&lt;part2&gt;" for example)
  * 
  * Returns: @str
+ * 
+ * Deprecated: 4.0.3: Not needed anymore because of the gda_sql_identifier_quote()
  */
 gchar *
 gda_sql_identifier_remove_quotes (gchar *str)
