@@ -84,7 +84,7 @@ gda_vprovider_data_model_class_init (GdaVproviderDataModelClass *klass)
 
 	server_class->get_name = gda_vprovider_data_model_get_name;
 
-	/* explicitely unimplement the DDL queries */
+	/* explicitly unimplement the DDL queries */
 	server_class->supports_operation = NULL;
         server_class->create_operation = NULL;
         server_class->render_operation = NULL;
@@ -348,7 +348,7 @@ virtualCreate (sqlite3 *db, void *pAux, int argc, const char *const *argv, sqlit
 	GdaDataModel *wrapper = NULL;
 	GString *sql;
 	gint i, ncols;
-	gchar *spec_name, *tmp;
+	gchar *spec_name;
 	GdaVConnectionTableData *td;
 
 	TRACE ();
@@ -407,9 +407,7 @@ virtualCreate (sqlite3 *db, void *pAux, int argc, const char *const *argv, sqlit
 
 	/* create the CREATE TABLE statement */
 	sql = g_string_new ("CREATE TABLE ");
-	tmp = gda_connection_quote_sql_identifier (GDA_CONNECTION (cnc), argv[2]);
-	g_string_append (sql, tmp);
-	g_free (tmp);
+	g_string_append (sql, argv[2]);
 	g_string_append (sql, " (");
 	for (i = 0; i < ncols; i++) {
 		GdaColumn *column;
@@ -445,7 +443,7 @@ virtualCreate (sqlite3 *db, void *pAux, int argc, const char *const *argv, sqlit
 		else if ((gtype == GDA_TYPE_BLOB) || (gtype == GDA_TYPE_BINARY))
 			type = "blob";
 		else if (gtype == G_TYPE_STRING)
-			type = "string";
+			type = "text";
 		else if ((gtype == G_TYPE_INT) || (gtype == G_TYPE_UINT) || 
 			 (gtype == G_TYPE_INT64) || (gtype == G_TYPE_UINT64) ||
 			 (gtype == GDA_TYPE_SHORT) || (gtype == GDA_TYPE_USHORT) ||
@@ -664,11 +662,8 @@ virtualColumn (sqlite3_vtab_cursor *cur, sqlite3_context *ctx, int i)
 			sqlite3_result_double (ctx, g_value_get_double (value));
 		else if (G_VALUE_TYPE (value) == GDA_TYPE_BLOB) {
 			GdaBlob *blob;
-			GdaBinary *bin;
 			blob = (GdaBlob *) gda_value_get_blob (value);
-			bin = (GdaBinary *) blob;
-			if (blob->op &&
-			    (bin->binary_length != gda_blob_op_get_length (blob->op)))
+			if (blob->op)
 				gda_blob_op_read_all (blob->op, blob);
 			sqlite3_result_blob (ctx, blob->data.data, blob->data.binary_length, SQLITE_TRANSIENT);
 		}
@@ -769,6 +764,10 @@ virtualUpdate (sqlite3_vtab *tab, int nData, sqlite3_value **apData, sqlite_int6
 			return SQLITE_READONLY;
 		}
 
+		newrow = gda_data_model_append_row (vtable->wrapper, NULL);
+		if (newrow < 0)
+			return SQLITE_READONLY;
+
 		for (i = 2; i < (nData - 1); i++) {
 			GType type;
 			GValue *value;
@@ -779,15 +778,11 @@ virtualUpdate (sqlite3_vtab *tab, int nData, sqlite3_value **apData, sqlite_int6
 				value = gda_value_new_null ();
 			/*g_print ("TXT #%s# => value %p (type=%s) apData[]=%p\n", sqlite3_value_text (apData [i]), value,
 			  g_type_name (type), apData[i]);*/
-			values = g_list_prepend (values, value);
+			values = g_list_append (values, value);
 		}
-		values = g_list_reverse (values);
-
-		newrow = gda_data_model_append_values (vtable->wrapper, values, NULL);
+		gda_data_model_set_values (vtable->wrapper, newrow, values, NULL);
 		g_list_foreach (values, (GFunc) gda_value_free, NULL);
 		g_list_free (values);
-		if (newrow < 0)
-			return SQLITE_READONLY;
 
 		*pRowid = newrow;
 	}
