@@ -1,5 +1,5 @@
 /* GDA jdbc provider
- * Copyright (C) 2008 - 2009 The GNOME Foundation.
+ * Copyright (C) 2008 The GNOME Foundation.
  *
  * AUTHORS:
  *      Vivien Malerba <malerba@gnome-db.org>
@@ -144,7 +144,7 @@ _gda_jdbc_meta_udt (GdaServerProvider *prov, GdaConnection *cnc,
 		    GdaMetaStore *store, GdaMetaContext *context, GError **error,
 		    const GValue *udt_catalog, const GValue *udt_schema)
 {
-	GdaDataModel *model = NULL;
+	GdaDataModel *model;
 	gboolean retval = TRUE;
 
 	TO_IMPLEMENT;
@@ -729,39 +729,3 @@ _gda_jdbc_meta_routine_par (GdaServerProvider *prov, GdaConnection *cnc,
 	TO_IMPLEMENT;
 	return TRUE;
 }
-
-gboolean
-_gda_mysql_meta__indexes_tab (GdaServerProvider *prov, GdaConnection *cnc, 
-			      GdaMetaStore *store, GdaMetaContext *context, GError **error)
-{
-	TO_IMPLEMENT;
-	return TRUE;
-}
-
-gboolean
-_gda_jdbc_meta_indexes_tab (GdaServerProvider *prov, GdaConnection *cnc, 
-			    GdaMetaStore *store, GdaMetaContext *context, GError **error,
-			    const GValue *table_catalog, const GValue *table_schema, const GValue *table_name,
-			    const GValue *index_name_n)
-{
-	TO_IMPLEMENT;
-	return TRUE;
-}
-
-gboolean
-_gda_jdbc_meta__index_cols (GdaServerProvider *prov, GdaConnection *cnc, 
-			    GdaMetaStore *store, GdaMetaContext *context, GError **error)
-{
-	TO_IMPLEMENT;
-	return TRUE;
-}
-
-gboolean
-_gda_jdbc_meta_index_cols (GdaServerProvider *prov, GdaConnection *cnc, 
-			   GdaMetaStore *store, GdaMetaContext *context, GError **error,
-			   const GValue *table_catalog, const GValue *table_schema,
-			   const GValue *table_name, const GValue *index_name)
-{
-	TO_IMPLEMENT;
-	return TRUE;
-}
