@@ -24,7 +24,7 @@
 #define __GDA_MYSQL_RECORDSET_H__
 
 #include <libgda/libgda.h>
-#include <providers-support/gda-pmodel.h>
+#include <providers-support/gda-data-select-priv.h>
 #include "gda-mysql-pstmt.h"
 
 G_BEGIN_DECLS
@@ -40,12 +40,12 @@ typedef struct _GdaMysqlRecordsetClass   GdaMysqlRecordsetClass;
 typedef struct _GdaMysqlRecordsetPrivate GdaMysqlRecordsetPrivate;
 
 struct _GdaMysqlRecordset {
-	GdaPModel                model;
-	GdaMysqlRecordsetPrivate *priv;
+	GdaDataSelect              model;
+	GdaMysqlRecordsetPrivate  *priv;
 };
 
 struct _GdaMysqlRecordsetClass {
-	GdaPModelClass             parent_class;
+	GdaDataSelectClass         parent_class;
 };
 
 GType
@@ -53,9 +53,21 @@ gda_mysql_recordset_get_type  (void) G_GNUC_CONST;
 GdaDataModel *
 gda_mysql_recordset_new       (GdaConnection            *cnc,
 			       GdaMysqlPStmt            *ps,
+			       GdaSet                   *exec_params,
 			       GdaDataModelAccessFlags   flags, 
 			       GType                    *col_types);
 
+
+gint
+gda_mysql_recordset_get_chunk_size (GdaMysqlRecordset  *recset);
+
+void
+gda_mysql_recordset_set_chunk_size (GdaMysqlRecordset  *recset,
+				    gint                chunk_size);
+
+gint
+gda_mysql_recordset_get_chunks_read (GdaMysqlRecordset  *recset);
+
 G_END_DECLS
 
 #endif
