@@ -25,6 +25,9 @@
 #include <glib/gi18n-lib.h>
 #include "gda-mysql-util.h"
 
+#include <libgda/sqlite/keywords_hash.h>
+#include "keywords_hash.c" /* this one is dynamically generated */
+
 /*
  * Create a new #GdaConnectionEvent object and "adds" it to @cnc
  *
@@ -79,83 +82,33 @@ _gda_mysql_make_error (GdaConnection  *cnc,
 	return event_error;
 }
 
-GType
-_gda_mysql_type_to_gda (MysqlConnectionData    *cdata,
-			enum enum_field_types   mysql_type)
+#ifdef GDA_DEBUG
+void
+_gda_mysql_test_keywords (void)
 {
-	GType gtype = 0;
-	switch (mysql_type) {
-	case MYSQL_TYPE_TINY:
-	case MYSQL_TYPE_SHORT:
-	case MYSQL_TYPE_LONG:
-	case MYSQL_TYPE_INT24:
-	case MYSQL_TYPE_YEAR:
-		gtype = G_TYPE_INT;
-		break;
-	case MYSQL_TYPE_LONGLONG:
-		gtype = G_TYPE_LONG;
-		break;
-	case MYSQL_TYPE_FLOAT:
-		gtype = G_TYPE_FLOAT;
-		break;
-	case MYSQL_TYPE_DECIMAL:
-	case MYSQL_TYPE_NEWDECIMAL:
-	case MYSQL_TYPE_DOUBLE:
-		gtype = G_TYPE_DOUBLE;
-		break;
-	case MYSQL_TYPE_BIT:
-	case MYSQL_TYPE_BLOB:
-		gtype = GDA_TYPE_BLOB;
-		break;
-	case MYSQL_TYPE_TIMESTAMP:
-	case MYSQL_TYPE_DATETIME:
-		gtype = GDA_TYPE_TIMESTAMP;
-		break;
-	case MYSQL_TYPE_DATE:
-		gtype = G_TYPE_DATE;
-		break;
-	case MYSQL_TYPE_TIME:
-		gtype = GDA_TYPE_TIME;
-		break;
-	case MYSQL_TYPE_NULL:
-		gtype = GDA_TYPE_NULL;
-		break;
-	case MYSQL_TYPE_STRING:
-	case MYSQL_TYPE_VAR_STRING:
-	case MYSQL_TYPE_SET:
-	case MYSQL_TYPE_ENUM:
-	case MYSQL_TYPE_GEOMETRY:
-	default:
-		gtype = G_TYPE_STRING;
+	V50test_keywords();
+	V51test_keywords();
+	V54test_keywords();
+	V60test_keywords();
+}
+#endif
+
+GdaSqlReservedKeywordsFunc
+_gda_mysql_get_reserved_keyword_func (MysqlConnectionData *cdata)
+{
+	if (cdata && cdata->short_version) {
+		switch (*cdata->short_version) {
+		case '5':
+			if (cdata->short_version[1] == '1')
+				return V51is_keyword;
+			if (cdata->short_version[1] == '0')
+				return V50is_keyword;
+			return V54is_keyword;
+		case '6':
+		default:
+			return V60is_keyword;
+		break;
+		}
 	}
-
-	/* g_print ("%s: ", __func__); */
-	/* switch (mysql_type) { */
-	/* case MYSQL_TYPE_TINY:  g_print ("MYSQL_TYPE_TINY");  break; */
-	/* case MYSQL_TYPE_SHORT:  g_print ("MYSQL_TYPE_SHORT");  break; */
-	/* case MYSQL_TYPE_LONG:  g_print ("MYSQL_TYPE_LONG");  break; */
-	/* case MYSQL_TYPE_INT24:  g_print ("MYSQL_TYPE_INT24");  break; */
-	/* case MYSQL_TYPE_YEAR:  g_print ("MYSQL_TYPE_YEAR");  break; */
-	/* case MYSQL_TYPE_LONGLONG:  g_print ("MYSQL_TYPE_LONGLONG");  break; */
-	/* case MYSQL_TYPE_FLOAT:  g_print ("MYSQL_TYPE_FLOAT");  break; */
-	/* case MYSQL_TYPE_DECIMAL:  g_print ("MYSQL_TYPE_DECIMAL");  break; */
-	/* case MYSQL_TYPE_NEWDECIMAL:  g_print ("MYSQL_TYPE_NEWDECIMAL");  break; */
-	/* case MYSQL_TYPE_DOUBLE:  g_print ("MYSQL_TYPE_DOUBLE");  break; */
-	/* case MYSQL_TYPE_BIT:  g_print ("MYSQL_TYPE_BIT");  break; */
-	/* case MYSQL_TYPE_BLOB:  g_print ("MYSQL_TYPE_BLOB");  break; */
-	/* case MYSQL_TYPE_TIMESTAMP:  g_print ("MYSQL_TYPE_TIMESTAMP");  break; */
-	/* case MYSQL_TYPE_DATETIME:  g_print ("MYSQL_TYPE_DATETIME");  break; */
-	/* case MYSQL_TYPE_DATE:  g_print ("MYSQL_TYPE_DATE");  break; */
-	/* case MYSQL_TYPE_TIME:  g_print ("MYSQL_TYPE_TIME");  break; */
-	/* case MYSQL_TYPE_NULL:  g_print ("MYSQL_TYPE_NULL");  break; */
-	/* case MYSQL_TYPE_STRING:  g_print ("MYSQL_TYPE_STRING");  break; */
-	/* case MYSQL_TYPE_VAR_STRING:  g_print ("MYSQL_TYPE_VAR_STRING");  break; */
-	/* case MYSQL_TYPE_SET:  g_print ("MYSQL_TYPE_SET");  break; */
-	/* case MYSQL_TYPE_ENUM:  g_print ("MYSQL_TYPE_ENUM");  break; */
-	/* case MYSQL_TYPE_GEOMETRY:  g_print ("MYSQL_TYPE_GEOMETRY");  break; */
-	/* default:  g_print ("UNKNOWN %d: MYSQL_TYPE_STRING", mysql_type);  break; */
-	/* } */
-	/* g_print ("\n"); */
-
-	return gtype;
+	return V60is_keyword;
 }
